/* Osm4j is a library that provides utilities to handle Openstreetmap data in java.
 *
 * Copyright (C) 2011  Sebastian Kuerten
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

package model.address.android;

import java.util.ArrayList;
import java.util.List;

import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;

/**
 * @author Sebastian Kuerten (sebastian.kuerten@fu-berlin.de)
 * 
 */
public class SqCity {

	private int id;
	private String name;

	/**
	 * Create a new SqCity instance.
	 * 
	 * @param id the city's id.
	 * @param name the city's name.
	 */
	public SqCity(int id, String name) {
		this.id = id;
		this.name = name;
	}

	/**
	 * @return the id
	 */
	public int getId() {
		return this.id;
	}

	/**
	 * @return the name
	 */
	public String getName() {
		return this.name;
	}

	/**
	 * Fetch a city by its id.
	 * 
	 * @param db
	 *            a Connection to use
	 * @param id
	 *            the id of the city
	 * 
	 * @return the city with the denoted id or null
	 */
	public static SqCity getCity(SQLiteDatabase db, int id) {
		String stmt = "select * from cities where id = " + id;
		Cursor cursor = db.rawQuery(stmt, null);

		SqCity city = null;
		if (cursor.moveToNext()) {
			city = new SqCity(cursor.getInt(0), cursor.getString(1));
		}

		cursor.close();
		return city;
	}

	/**
	 * Fetch a list of resulting cities.
	 * 
	 * @param db
	 *            a Connection to use
	 * @param querystring
	 *            the name to search for.
	 * @param exact
	 *            whether to use wildcards in like-search
	 * @param limit
	 *            a number limiting the number of returned values.
	 * @return the list of results.
	 */
	public static List<SqCity> getCities(SQLiteDatabase db, String querystring, boolean exact,
			int limit) {
		ArrayList<SqCity> list = new ArrayList<SqCity>();
		String query = exact ? querystring : "%" + querystring + "%";
		String stmt = "select * from cities where name like '" + query + "' limit "
				+ limit;
		Cursor cursor = db.rawQuery(stmt, null);

		while (cursor.moveToNext()) {
			SqCity city = new SqCity(cursor.getInt(0), cursor.getString(1));
			list.add(city);
		}

		cursor.close();
		return list;
	}

	/**
	 * Retrieve the first postcode associated with this city via joining the cities with roads
	 * and the roads with the postcodes.
	 * 
	 * @param db
	 *            a Connection to use
	 * @return the first postcode that can be found to be associated with this city or null.
	 */
	public SqPostcode getRandomPostcode(SQLiteDatabase db) {
		String stmt = "select postcodes.id, postcodes.code from cities " +
				"join roads on cities.id = roads.city_id " +
				"join roads_postcodes on roads.id = roads_postcodes.roads_id " +
				"join postcodes on roads_postcodes.postcodes_id = postcodes.id " +
				"where cities.id = " + id + " limit 1";
		Cursor cursor = db.rawQuery(stmt, null);

		SqPostcode postcode = null;
		if (cursor.moveToNext()) {
			int pid = cursor.getInt(0);
			String code = cursor.getString(1);
			postcode = new SqPostcode(pid, code);
		}

		cursor.close();

		return postcode;
	}

	@Override
	public int hashCode() {
		return this.id;
	}

	@Override
	public boolean equals(Object other) {
		if (other instanceof SqCity) {
			SqCity o = (SqCity) other;
			return o.id == this.id;
		}
		return false;
	}
}
