/* Osm4j is a library that provides utilities to handle Openstreetmap data in java.
 *
 * Copyright (C) 2011  Sebastian Kuerten
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

package model.address.android;

import java.util.ArrayList;
import java.util.List;

import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;

/**
 * @author Sebastian Kuerten (sebastian.kuerten@fu-berlin.de)
 * 
 */
public class SqPostcode {

	private int id;
	private String code;

	/**
	 * Create a new instance of SqPostcode.
	 * 
	 * @param id the database id.
	 * @param code the postcode.
	 */
	public SqPostcode(int id, String code) {
		this.id = id;
		this.code = code;
	}

	/**
	 * @return the id
	 */
	public int getId() {
		return this.id;
	}

	/**
	 * @return the name
	 */
	public String getPostcode() {
		return this.code;
	}

	/**
	 * Fetch a list of resulting postcodes.
	 * 
	 * @param db
	 *            a Connection to use
	 * @param querystring
	 *            the name to search for.
	 * @param limit
	 *            a number limiting the number of returned values.
	 * @return the list of results.
	 */
	public static List<SqPostcode> getPostcodes(SQLiteDatabase db, String querystring, int limit) {
		ArrayList<SqPostcode> list = new ArrayList<SqPostcode>();
		String stmt = "select * from postcodes where code like '%" + querystring + "%' limit "
				+ limit;
		Cursor cursor = db.rawQuery(stmt, null);

		while (cursor.moveToNext()) {
			SqPostcode postcode = new SqPostcode(cursor.getInt(0), cursor.getString(1));
			list.add(postcode);
		}

		cursor.close();
		return list;
	}


	@Override
	public int hashCode() {
		return this.id;
	}

	@Override
	public boolean equals(Object other) {
		if (other instanceof SqPostcode) {
			SqPostcode o = (SqPostcode) other;
			return o.id == this.id;
		}
		return false;
	}
}
